
import java.net.*;
import java.util.Random;

import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.namespace.*;
import com.bullhorn.apiservice.*;
import com.bullhorn.apiservice.query.*;
import com.bullhorn.apiservice.result.*;
import com.bullhorn.apiservice.session.*;
import com.bullhorn.entity.candidate.CandidateDto;
import com.bullhorn.entity.candidate.CandidateEducationDto;
import com.bullhorn.entity.candidate.CandidateWorkHistoryDto;
import com.bullhorn.entity.emb.Address;
import com.bullhorn.entity.lists.CategoryDto;
import com.bullhorn.entity.lists.SkillDto;

public class Candidates {

    private static final QName SERVICE_NAME = new QName("http://apiservice.bullhorn.com/", "ApiService");

    public static void main(String[] args) throws Exception {

        String username = "yourusername";
        String password = "yourpassword";
        String apiKey = "yourapikey";
        String wsdlUrl = "https://api.bullhornstaffing.com/webservices-1.1/?wsdl"; 
        
       
        // obtain the API web service
        URL serviceUrl = new URL(ApiService_Service.class.getResource("."), wsdlUrl);
        ApiService service = new ApiService_Service(serviceUrl, SERVICE_NAME).getApiServicePort();

        // Login to obtain an API session
        ApiSession currentSession = service.startSession(username, password, apiKey);

        Random generator = new Random();
        int r = generator.nextInt();
        
        Address candidateAddress = new Address();
        candidateAddress.setAddress1("1234 Fictional Street");
        candidateAddress.setAddress2("Apt. 4");
        candidateAddress.setCity("Boulder");
        candidateAddress.setState("Colorado");
        candidateAddress.setZip("12345");
        candidateAddress.setCountryID(1);

        
        CandidateDto candidateDto = new CandidateDto();
        candidateDto.setFirstName("Delvan");
        candidateDto.setLastName("Minke");
        candidateDto.setName("Delvan Minke");
        candidateDto.setPhone("4046537890");
        candidateDto.setEmail("dminke@test.com");
        candidateDto.setAddress(candidateAddress);
        candidateDto.setUsername("dminke"+r);
        candidateDto.setStatus("Available");
        candidateDto.setDescription("Most fun candidate to work with!");
        candidateDto.setOwnerID(currentSession.getUserId());
        candidateDto.setUserTypeID(35);
        candidateDto.setCategoryID(45);
         
        candidateDto.setPassword("password");
       
        ApiSaveResult results = service.save(currentSession, candidateDto);
        currentSession = results.getSession();
        
        CandidateDto savedCandidate = (CandidateDto)results.getDto();
     
     
        XMLGregorianCalendar startDate;
        startDate = DatatypeFactory.newInstance().newXMLGregorianCalendar();
        startDate.setDay(1);
        startDate.setMonth(9);
        startDate.setYear(2010);
        startDate.setHour(8);
        startDate.setMinute(30);
        startDate.setSecond(0);
        
        XMLGregorianCalendar endDate;
        endDate = DatatypeFactory.newInstance().newXMLGregorianCalendar();
        endDate.setDay(1);
        endDate.setMonth(9);
        endDate.setYear(2011);
        endDate.setHour(8);
        endDate.setMinute(30);
        endDate.setSecond(0);
        
        // Add Candidate work history associated with the candidate above. Must be created after the candidate is saved
        CandidateWorkHistoryDto savedCandidateWorkHistory = new CandidateWorkHistoryDto();
        savedCandidateWorkHistory.setCandidateID(savedCandidate.getUserID());
        savedCandidateWorkHistory.setStartDate(startDate);
        savedCandidateWorkHistory.setEndDate(endDate);
        savedCandidateWorkHistory.setTitle("Architect");
        savedCandidateWorkHistory.setComments("Worked in Avaya till 2009.");
        service.save(currentSession, savedCandidateWorkHistory);
        // System.out.println("Candidate WH is: "+savedCandidateWorkHistory.getComments());
              
       // Add Candidate education associated with the candidate above. Must be created after the candidate is saved
       CandidateEducationDto savedCandidateEducation = new CandidateEducationDto();
       savedCandidateEducation.setCandidateID(savedCandidate.getUserID());
       savedCandidateEducation.setStartDate(startDate);
       savedCandidateEducation.setEndDate(endDate);
       savedCandidateEducation.setState("CO");
       savedCandidateEducation.setComments("MS in Computer Science");
       service.save(currentSession, savedCandidateEducation);
       //    System.out.println("Candidate Education is: "+savedCandidateEducation.getComments());
            
          
		// Get the list of categories for the corporation
		DtoQuery categoryQuery = new DtoQuery();
		categoryQuery.setEntityName("Category");
		categoryQuery.setWhere("enabled = 1");
		ApiQueryResult categoryResult = service.query(currentSession, categoryQuery);
		currentSession = categoryResult.getSession();
		     
		if (!categoryResult.getIds().isEmpty())
		   {
		      for (int i1 =0; i1< categoryResult.getIds().size() ; i1++)
		      {
		      	  ApiFindResult category = service.find(currentSession, "Category", categoryResult.getIds().get(i1));
		       	  currentSession = category.getSession();
		          CategoryDto thisCategory = (CategoryDto)category.getDto();
		          System.out.println("Found category using find() method: " +thisCategory.getCategoryID() + ", " + thisCategory.getOccupation());
		      }
		   } 
		        
		// Associate the new candidate DTO with two categories, get category id from the query above
		service.associate(currentSession, "Candidate", savedCandidate.getUserID(), "categories" , 254953);
		service.associate(currentSession, "Candidate", savedCandidate.getUserID(), "categories" , 254954);
		        
		        
		        
		// Get a list of skills for this corp
		DtoQuery skillQuery = new DtoQuery();
		skillQuery.setEntityName("Skill");
		skillQuery.setMaxResults(10);
		skillQuery.setWhere("enabled = 1");
		ApiQueryResult skillResult = service.query(currentSession, skillQuery);
		currentSession = skillResult.getSession();
		if (!skillResult.getIds().isEmpty())
		   {
		     for (int i1 =0; i1< skillResult.getIds().size() ; i1++)
		     {
		    	  ApiFindResult primarySkills = service.find(currentSession, "Skill", skillResult.getIds().get(i1));
		      	  currentSession = primarySkills.getSession();
		          SkillDto thisSkillSet = (SkillDto)primarySkills.getDto();
		          System.out.println("Found primary skills using find() method: " +thisSkillSet.getSkillID() + ", " + thisSkillSet.getName());
		     }
		   } 
		
		// Add skills to the candidate
		service.associate(currentSession, "Candidate", savedCandidate.getUserID(), "primarySkills" , 10093);
       
    
        // Update a candidate
        DtoQuery candidateUpdateQuery = new DtoQuery();
        candidateUpdateQuery.setEntityName("Candidate");
        candidateUpdateQuery.setMaxResults(10);
        candidateUpdateQuery.setWhere("FirstName = 'Brad'");
        ApiQueryResult queryUpdateResult = service.query(currentSession, candidateUpdateQuery);
        currentSession = queryUpdateResult.getSession();

        if (!queryUpdateResult.getIds().isEmpty())
        {
          for (int i =0; i< queryUpdateResult.getIds().size() ; i++)
          {
        	  ApiFindResult candidate = service.find(currentSession, "Candidate", queryUpdateResult.getIds().get(i));
        	  currentSession = candidate.getSession();
              CandidateDto thisCandidate = (CandidateDto)candidate.getDto();
              System.out.println("Found candidate using find() method: " +thisCandidate.getName() + " of phone number " +thisCandidate.getPhone());
           
              // Update the candidate's phone number
              thisCandidate.setPhone("6661012222");
              
              ApiSaveResult resultSavePhone = service.save(currentSession, thisCandidate);
              currentSession = resultSavePhone.getSession();
          }
        }  
        
        /* Use the find operation to look for a candidate record you want to delete. Then set the IsDeleted flag on that record to mark it for deletion. */
        DtoQuery candidateDeleteQuery = new DtoQuery();
        candidateDeleteQuery.setEntityName("Candidate");
        candidateDeleteQuery.setMaxResults(10);
        candidateDeleteQuery.setWhere("FirstName = 'Brad'");
        ApiQueryResult queryDeleteResult = service.query(currentSession, candidateDeleteQuery);
        currentSession = queryDeleteResult.getSession();

                if (!queryDeleteResult.getIds().isEmpty())
                {
                 
                  for (int i =0; i< queryDeleteResult.getIds().size() ; i++)
                  {
                	  ApiFindResult candidate = service.find(currentSession, "Candidate",
                			  queryDeleteResult.getIds().get(i));
                	  currentSession = candidate.getSession();
                      CandidateDto thisCandidate = (CandidateDto)candidate.getDto();
                      thisCandidate.setIsDeleted(true);
                 }

    }
  }
}